#!/usr/bin/env python
# -*- coding: utf-8 -*-
#*******************************************************************************
#**  This file is part of HgWeb Manager.                                     ***
#**                                                                          ***
#**  Copyright (C) 2014                                                      ***
#**  CodeGNU Solutions <Licensing _AT_ CodeGNU _DOT_ com>                    ***
#**                                                                          ***
#**  This program is free software: you can redistribute it and/or modify it ***
#**  under the terms of the GNU Affero General Public License as published   ***
#**  by the Free Software Foundation, either version 3 of the License, or    ***
#**  (at your option) any later version.                                     ***
#**                                                                          ***
#**  This program is distributed in the hope that it will be useful, but     ***
#**  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
#**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
#**  See the GNU Affero General Public License for more details.             ***
#**                                                                          ***
#**  You should have received a copy of the GNU Affero General Public License***
#**  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
#*******************************************************************************

# The current version of the application
VERSION = '0.2.0'
# The current copyright years.
YEARS = '2014'
# A short description of the application
DESCRIPTION = 'Manages HgWeb Repositories'
# A long description of the application
LONG_DESCRIPTION = 'An application to simplify the management of repositories shared through the Mercurial web publishing method.'

"""
 IMPORTS
"""
import configuration as config


# Configuration values for HgWebManager.
settings = config.Manager()

def is_hgWeb_user():
	"""Determines if the current running user is the expected HgWeb user.

	 @return Gives true when the user is the expected HgWeb user, false
	  else-wise.
	"""
	import getpass

	# FIXME: This isn't a secure check as it is based upon the environmental variable.
	if settings.HgUser == getpass.getuser():
		return True
	else:
		return False


def __extract_values(args):
	"""Pulls the creation arguments out of the command-line.

	 @param[in] args	The command-line argument processor containing the
					creation argument values.

	 @return A managed repository object.
	"""
	import manrepo

	managed = manrepo.Repository()
	if args.repository:
		managed.StorageName = args.repository

	if args.name:
		managed.DisplayName = args.name

	if args.description:
		managed.Description = args.description

	if args.contact:
		managed.Contact = args.contact
	return managed

def main(args):
	import argparse
	import manrepo
	import manager

	if not is_hgWeb_user():
		print >>sys.stderr, "Must execute as the Mercurial Web manager."
		exit(1)

	parser = argparse.ArgumentParser(description=DESCRIPTION)
	parser.add_argument("repository", action="store", help='The storage-name of the repository to perform an action upon.')
	parser.add_argument("-a", "--action", action="store", nargs=1, type=str, choices=['create','modify','delete'], help='Performs an action upon a managed HgWeb repository.')
	parser.add_argument("-n", "--name", action="store", nargs='?', default=None, help='The display name of the repository.')
	parser.add_argument("-d", "--description", action="store", nargs='?', default=None, help='The description of the repository.')
	parser.add_argument("-c", "--contact", action="store", nargs='?', default=None, help='The contact point of a repository.')
	parser.add_argument("-r", "--rename", action="store", nargs='?', default=None, help='The new storage-name for the repository.')
	args = parser.parse_args()
	repo = __extract_values(args)


	if 'create' == args.action[0]:
		if manager.create(repo):
			exit(0)
		else:
			exit(1)
	elif 'modify' == args.action[0]:
		currentStorageName = repo.StorageName
		if args.rename:
			repo.StorageName = args.rename
		if manager.modify(repo, currentStorageName):
			exit(0)
		else:
			exit(1)
	elif 'delete' == args.action[0]:
		if manager.delete(repo):
			exit(0)
		else:
			exit(1)

	print >>sys.stderr, "Failure determine action request %s." % args.action
	exit(2)

if __name__ == "__main__":
	import sys

	# Display license
	print "HWM %s Copyright (C) %s CodeGNU Solutions" % (VERSION, YEARS)
	print "HWM comes with ABSOLUTELY NO WARRANTY;"
	print "This is free software, and you are welcome to redistribute it"
	print "under certain conditions; see the LICENSE file for details,"
	print "or the Free Software Foundation's AGPL.\n"

	main(sys.argv)
